CREATE TABLE device
(
    id                                BIGINT  NOT NULL,
    org_key                           VARCHAR NOT NULL,
    kernel_version                    VARCHAR NULL,
    os                                VARCHAR NULL,
    os_version                        VARCHAR NULL,
    last_sensor_started_at            BIGINT NULL,
    last_full_sync_event_ingress_at   BIGINT NULL,
    created_at                        TIMESTAMP NULL,
    modified_at                       TIMESTAMP NULL,
    PRIMARY KEY (id)
);

CREATE TABLE runtime
(
    id              BIGSERIAL NOT NULL,
    device_id       BIGINT NOT NULL,
    runtime_name    VARCHAR NULL,
    runtime_version VARCHAR NULL,
    created_at      TIMESTAMP NULL,
    modified_at     TIMESTAMP NULL,
    PRIMARY KEY (id),
    FOREIGN KEY (device_id) REFERENCES device (id),
    UNIQUE (device_id, runtime_name)
);

CREATE TABLE container
(
    id                    BIGSERIAL NOT NULL,
    device_id             BIGINT    NOT NULL,
    runtime_id            BIGINT    NOT NULL,
    container_id          VARCHAR   NOT NULL,
    c_group               VARCHAR NULL,
    name                  VARCHAR NULL,
    status                VARCHAR NULL,
    root_path             VARCHAR NULL,
    image_name            VARCHAR   NOT NULL,
    image_hash            VARCHAR   NOT NULL,
    ip_address            VARCHAR[] NULL,
    hostname              VARCHAR NULL,
    privileged            BOOLEAN NULL,
    start_time            TIMESTAMP NULL,
    entrypoint            VARCHAR NULL,
    last_event_ingress_at BIGINT NULL,
    created_at            TIMESTAMP NULL,
    modified_at           TIMESTAMP NULL,
    PRIMARY KEY (id),
    FOREIGN KEY (runtime_id) REFERENCES runtime (id),
    FOREIGN KEY (device_id) REFERENCES device (id),
    UNIQUE (device_id, runtime_id, container_id)
);